@@ -1,4 +1,4 @@
-import yaml
+import yamlenv
 from .dotdict import Dotdict
 
 
@@ -13,7 +13,7 @@ class Hparam(Dotdict):
 
     def _load_hparam(self, filename: str) -> dict:
         stream = open(filename, 'r')
-        docs = yaml.load_all(stream, Loader=yaml.SafeLoader)
+        docs = yamlenv.load_all(stream, Loader=yamlenv.SafeLoader)
         hparam_dict = dict()
         for doc in docs:
             for k, v in doc.items():
